Nemoa
=====

.. image:: https://travis-ci.org/frootlab/nemoa.svg?branch=master
   :target: https://travis-ci.org/frootlab/nemoa

.. image:: https://readthedocs.org/projects/nemoa/badge/?version=latest
    :target: https://nemoa.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://badge.fury.io/py/nemoa.svg
    :target: https://badge.fury.io/py/nemoa

*Nemoa* is a data analysis framework for collaborative data science and
enterprise application. Nemoa is open source and based on the `Python`_
programming language.

The key goal of Nemoa is to provide a long-term data analysis framework, which
seemingly integrates into existing enterprise data environments and thereby
supports collaborative data science. To achieve this goal Nemoa orchestrates
established frameworks like `TensorFlow®`_ and `SQLAlchemy`_ and dynamically
extends their capabilities by **community driven** algorithms for `probabilistic
graphical modeling`_, `machine learning`_ and `structured data-analysis`_.

- **Documentation**: https://nemoa.readthedocs.io
- **Issues**: https://github.com/frootlab/nemoa/issues
- **Source**: https://github.com/frootlab/nemoa

Install
-------

Install the latest version of nemoa::

    $ pip install nemoa

Contribute
----------

Contributors are very welcome! Feel free to report bugs and feature requests to
the `issue tracker`_ provided by GitHub. You can also follow the progress of the
project by joining the `google group`_.

License
-------

Nemoa is available free for any use under the `GPLv3 license`_::

   Copyright (c) 2019 Frootlab Developers
   Patrick Michl <patrick.michl@gmail.com>

.. _Python: https://www.python.org/
.. _TensorFlow®: https://www.tensorflow.org/
.. _SQLAlchemy: https://www.sqlalchemy.org/
.. _GPLv3 license: https://www.gnu.org/licenses/gpl.html
.. _issue tracker: https://github.com/frootlab/nemoa/issues
.. _frootlab: https://github.com/frootlab
.. _probabilistic graphical modeling:
    https://en.wikipedia.org/wiki/Graphical_model
.. _machine learning: https://en.wikipedia.org/wiki/Machine_learning
.. _structured data-analysis:
    https://en.wikipedia.org/wiki/Structured_data_analysis_(statistics)
.. _GPLv3 license: https://www.gnu.org/licenses/gpl.html
.. _issue tracker: https://github.com/frootlab/nemoa/issues
.. _google group: http://groups.google.com/group/nemoa
.. _FrootLab: https://github.com/frootlab
